@@ -272,7 +272,7 @@ class OssFilesPipeline(MediaPipeline):
                 for u in urls:
                     if '%' not in u:
                         #防止资源链接出现空格等特殊字符,eg:https://www.semiee.com/file/Infineon/Infineon-TLE9261-3BQX V33.pdf
-                        u = quote(u, safe='/:') 
+                        u = quote(u, safe='/:&?') 
                     u = Request(u)
                     if item._header: 
                         # 配置资源链接上一请求的header和referer,
